Crate agdb_derive
source ·Derive Macros
- The derive macro to add
agdbcompatibility to user defined types. It implements [agdb::DbUserValue] for the type automatically to allow your type to be read and stored from/to the database. If your type contains a fielddb_id: Option<agdb::DbId>it will be treated specially and will additionally allow shorthand inserts/updates of the elements directly.